# MedAId :stethoscope:

This is a Python package designed for working with tabular data. While it is optimized for medical data use cases, it can be adapted to work with any kind of tabular dataset.

## Installation

This package is available on PyPI. Clone the repository and install the package using the following commands:

```bash
pip install medaid
```
## More Info
For more detailed information about the package navigate to `notebook.ipynb` (polish version) or `notebook_eng.ipynb` (english version) file.
